%######################################################################### 
%SANDWICH RADOME SIMULATION 
%######################################################################### 

 
%INPUT DATA 
 
%SIMULATION PROPERTIES 
clear; 
clc; 
N = 3;       %Number of layers 
fmin= 0.1;     %Minimum Frequency (GHz) 
fmax= 25;     %Maximum Frequency (GHz) 
pol= 2;      %Polarization Type Parallel(Tm) (1), Perpendicular(Te) (2) 
theta= [0 30 60]; %Angles to simulate

%Constants 
E0=8.85e-12;  
Mu0=12.5664e-7;  
c=1/sqrt(E0*Mu0);  
 
%SANDWICH PARAMETERS 
 
 %Layer 1
 Ei(1)= 4; %Permittivity 
 t(1)= 0.8255e-2;  %Layer Thickness (m) 
 tand(1)= 0.015; %Loss tangent 
 
 %Layer 2
 Ei(2)= 1.08; %Permittivity 
 t(2)= 24e-3;  %Layer Thickness (m) 
 tand(2)= 0.001; %Loss tangent 
 
 %Layer 3
 Ei(3)= 3.8; %Permittivity 
 t(3)= 0.9e-03;  %Layer Thickness (m) 
 tand(3)= 0.001; %Loss tangent 
 
 %Layer 4
 Ei(4)= 1.1; %Permittivity 
 t(4)= 0.3302e-2;  %Layer Thickness (m) 
 tand(4)= 0.001; %Loss tangent 
 
 %Layer 5
 Ei(5)= 3.23; %Permittivity 
 t(5)= 0.0762e-02;  %Layer Thickness (m) 
 tand(5)= 0.016; %Loss tangent 
 
 %Layer 6
 Ei(6)= 1.1; %Permittivity 
 t(6)= 0.3302e-2;  %Layer Thickness (m) 
 tand(6)= 0.001; %Loss tangent 
 
 %Layer 7
 Ei(7)= 3.23; %Permittivity 
 t(7)= 0.0762e-2;  %Layer Thickness (m) 
 tand(7)= 0.016; %Loss tangent 
 
 %Layer 8
 Ei(8)= 1.1; %Permittivity 
 t(8)= 0.3302e-2;  %Layer Thickness (m) 
 tand(8)= 0.001; %Loss tangent 
 
 %Layer 9
 Ei(9)= 3.23; %Permittivity 
 t(9)= 0.0762e-2;  %Layer Thickness (m) 
 tand(9)= 0.016; %Loss tangent 
 
 %Layer 10
 Ei(10)= 1; %Permittivity
 t(10)= 1;  %Layer Thickness (m) 
 tand(10)= 1; %Loss tangent
 
 %Free Space Layer (Do not alter)
 Ei(N+1)= 1; %Permittivity 
 t(N+1)= 100000;  %Layer Thickness (m) 
 tand(N+1)= 0; %Loss tangent 
 



f=linspace(fmin,fmax,50); %Matrix with simulation frequencies 
thetaradian=theta.*(pi/180); %Angle of incidence (Radian) 

    
    sintheta=sin(thetaradian); 
    costheta=cos(thetaradian);

 


for m=1:length(theta)
    sintheta1=sintheta(m);
    costheta1=costheta(m);

    %Total reflection and transmission coefficients
    for k =1:length(f); 
    Gamma=2*(pi/(c/(f(k)*1e9)));
    TotalMatrix=1; 
 
 %Characteristic layer impedance 
 for i=1:N+1 
 Er(i)=Ei(i)*(1-(j*tand(i)));
 if pol==1 
 Z(i)=sqrt(Er(i)-(sintheta1^2))/(Er(i)*costheta1); 
 elseif pol==2 
 Z(i)=costheta1/sqrt(Er(i)-(sintheta1^2));  
 end 
 end 
 
 %Reflection and transmission for the different layers 
 refl(1)=(Z(1)-1)/(Z(1)+1); 
 trans(1)=sqrt(1-refl(1)^2); 
 for i=2:N+1 
 refl(i)=(Z(i)-Z(i-1))/(Z(i)+Z(i-1)); 
 trans(i)=sqrt(1-refl(i)^2);
 end 
 
 %Wave matrix calculation
 for i =1:(N)  
 M=exp(j*Gamma*t(i)*sqrt(Er(i)-(sintheta1^2))); 
 Mc=exp(-j*Gamma*t(i)*sqrt(Er(i)-(sintheta1^2))); 
 TotalMatrix=TotalMatrix*(1/trans(i)*[M,refl(i)*Mc;refl(i)*M,Mc]);
 end 
 
 %Total reflection and transmission coefficients of the structure 
 TotalMatrix=1/trans(N+1)*TotalMatrix*[1 refl(N+1); refl(N+1) 1]; 
 reflection(k)=TotalMatrix(2,1)/TotalMatrix(1,1); 
 transmission(k)=1/TotalMatrix(1,1); 
 
end

 Transabs=abs(transmission);
 Reflabs=abs(reflection);
 Transabsdb=mag2db(Transabs);
 Reflabsdb=mag2db(Reflabs);



%Plot the transmission and reflection coefficients in dB:
figure(1)
style=['k--';'k-x';'k-v'];
plot(f,Transabsdb,style(m,1:3));
hold on
grid; 
xlabel('Frequency (GHz)'); 
ylabel('Transmission loss (dB)'); 
legend('0^{\circ}','30^{\circ}','60^{\circ}','Location','EastOutside');

figure(2)
style=['k--';'k-x';'k-v'];
plot(f,Reflabsdb,style(m,1:3));
hold on
grid; 
xlabel('Frequency (GHz)'); 
ylabel('Reflection loss (dB)'); 
legend('0^{\circ}','30^{\circ}','60^{\circ}','Location','EastOutside');



end


