%############################################################### 
%SANDWICH RADOME SIMULATION WITH IMPEDANCE COMPENSATION
%############################################################### 

 
%INPUTS 
 
%Structure properties 
clear; 
clc; 
N = 4;       %Number of layers 
fmin= 2.6;     %Lower Frequency (GHz) 
fmax= 4;     %Higher Frequency (GHz) 
pol= 2;      %Parallel(Tm) (1), Perpendicular(Te) (2) 



%Load data for comparison
%load('S11_DUT_SUBSTRAT.mat');
%load('S21_DUT_SUBSTRAT.mat');
%load('S12_DUT_SUBSTRAT.mat');
%load('S22_DUT_SUBSTRAT.mat');
%load('Freq.mat');

% load('S11_2lag.mat');
% load('S21_2lag.mat');
% load('S12_2lag.mat');
% load('S22_2lag.mat');
% load('Freq_2lag.mat');

%Load data from HFSS
%load('S11_Irene.mat');
%load('S21_Irene.mat');
%load('freq_Irene.mat');

%Load data from CST
% load('S11_2lag.mat');
% load('S21_2lag.mat');
% load('Freq_2lag.mat');
 
%Constants 
E0=8.85e-12;  
Mu0=12.5664e-7;  
c=1/sqrt(E0*Mu0);
a=72.136e-3;
b=34.036e-3;
fco=2.078e9;
lambda_co=c/fco;
% S11_DUT_ABS=abs(S11_DUT);

%Layer parameters 
 %Layer 1
 Ei(1)= 4.4; %Permittivity 
 t(1)= 1.6e-03;  %Layer Thickness (m) 
 tand(1)= 0.02; %Loss tangent 
 
 %Layer 2
 Ei(2)= 1.08; %Permittivity 
 t(2)= 24e-03;  %Layer Thickness (m) 
 tand(2)= 0.001; %Loss tangent 
 
 %Layer 3
 Ei(3)= 3.8; %Permittivity 
 t(3)= 0.9e-03;  %Layer Thickness (m) 
 tand(3)= 0.001; %Loss tangent 
 
 %Layer 4
 Ei(4)= 2.9; %Permittivity 
 t(4)= 0.5e-3;  %Layer Thickness (m) 
 tand(4)= 0.01; %Loss tangent 
 
 %Layer 5
 Ei(5)= 1; %Permittivity 
 t(5)= 1000;  %Layer Thickness (m) 
 tand(5)= 0.0; %Loss tangent 
 
 %Layer 6
 Ei(6)= 1.1; %Permittivity 
 t(6)= 0.5842e-2;  %Layer Thickness (m) 
 tand(6)= 0.001; %Loss tangent 
 
 %Layer 7
 Ei(7)= 3.23; %Permittivity
 t(7)= 0.0762e-2;  %Layer Thickness (m) 
 tand(7)= 0.016; %Loss tangent 
 
 %Layer 8
 Ei(8)= 1.1; %Permittivity 
 t(8)= 0.3302e-2;  %Layer Thickness (m) 
 tand(8)= 0.001; %Loss tangent 
 
 %Layer 9
 Ei(9)= 3.23; %Permittivity 
 t(9)= 0.0762e-2;  %Layer Thickness (m) 
 tand(9)= 0.016; %Loss tangent 
 
 %Layer 10
 Ei(10)= 1; %Permittivity 
 t(10)= 1;  %Layer Thickness (m) 
 tand(10)= 1; %Loss tangent
 
 %Free Space Layer (Do not alter)
 Ei(N+1)= 1; %Permittivity
 t(N+1)= 1000;  %Layer Thickness (m) 
 tand(N+1)= 0; %Loss tangent 

 theta= [0];

f=linspace(fmin*1e9,fmax*1e9,801); %Frequency matrix
%f2=linspace(2.6e9,4e9,29); %Optional frequency matrix external data plots
thetaradian=theta.*(pi/180); %Angle of incidence (Radian) 




    sintheta=sin(thetaradian); 
    costheta=cos(thetaradian);
 

for m=1:length(theta)
 
    sintheta1=sintheta(m);
    costheta1=costheta(m);

%Calculate the total reflection and transmission coefficients
for k =1:length(f); 
 lambda_freespace(k)=c/(f(k)); 
 Gamma=2*(pi/lambda_freespace(k));
 total=1;
 
 
 %Characateristic layer impedance 
 Z_w(k)=(1/sqrt(1-((fco/f(k)))^2));
 Er(1)=Ei(1)*(1-(j*tand(1)));
 Z(1)=(costheta1/sqrt(Er(1)-(sintheta1^2)))/Z_w(k);
 for i=2:N+1 
 Er(i)=Ei(i)*(1-(j*tand(i)));
 if pol==1 
 Z(i)=(sqrt(Er(i)-(sintheta1^2))/(Er(i)*costheta1))/Z_w(k); 
 elseif pol==2 
 Z(i)=(costheta1/sqrt(Er(i)-(sintheta1^2)))/Z_w(k);  
 end 
 end 
 
 %Reflection and transmission for the different layers 
 reflection(1)=((Z(1)-1)/(Z(1)+1)); 
 transmission(1)=sqrt(1-reflection(1)^2); 
 %tao(1)=1+ro(1);
 for i=2:N+1 
 reflection(i)=((Z(i)-Z(i-1))/(Z(i)+Z(i-1))); 
 transmission(i)=sqrt(1-reflection(i)^2);
 %tao(i)=1+ro(i);
 end 
 
 %Wave matrix calculation 
 for i =1:(N)  
 A=exp(j*Gamma*t(i)*sqrt(Er(i)-(sintheta1^2))); 
 Ac=exp(-j*Gamma*t(i)*sqrt(Er(i)-(sintheta1^2)));
 total=total*(1/transmission(i)*[A,reflection(i)*Ac;reflection(i)*A,Ac]);
 end 
 
 %Total reflection and transmission coefficients of the structure 
 total=1/transmission(N+1)*total*[1 reflection(N+1); reflection(N+1) 1]; 
 reflection_loss(k)=total(2,1)/total(1,1); 
 transmission_loss(k)=1/total(1,1); 

end

 Transabs=abs(transmission_loss);
 Reflabs=abs(reflection_loss);
 Transabsdb=-mag2db(Transabs);
 Reflabsdb=-mag2db(Reflabs);



%Plot
figure(1)
plot(Freq,mag2db(abs(S21_DUT_SUBSTRAT)),'k-.',f,-Transabsdb,'k-');
hold on
grid on;
axis ([fmin*1e9 fmax*1e9 -0.8 -0.2])
xlabel('Frequency (GHz)'); 
ylabel('Reflection loss (dB)'); 
legend('Measured','Matlab','Location','EastOutside');

end


