%############################################################### 
%TRANSMISSION AND REFLECTION THROUGH MULTILAYER DIELECTRIC WALLS 
%############################################################### 

function Error = ABCD(E)
%INPUTS 
 
%Structure properties 
%clear; 
%clc; 
N = 4;       %number of layers 
fmin= 2.6;     %Minimum Frequency (GHz) 
fmax= 4.0;     %Maximum Frequency (GHz) 
pol= 2;      %Polarization Type Parallel(Tm) (1), Perpendicular(Te) (2) 
 
%Constants 
E0=8.85e-12;  
Mu0=12.5664e-7;  
c=1/sqrt(E0*Mu0); 
a=72.136e-3;
fco=2.078e9;
lambda_co=c/fco;

%Load measurements data from file
load('S11_DUT1.mat');
load('S21_DUT1.mat');
load('S11_DUT1.mat');
load('S21_DUT1.mat');

%load('Freq_Irene.mat');
%load('S11_Irene.mat');
%load('S21_Irene.mat');

%S11=S11abslinear.';
%S12=S12abslinear.';
%S21=S21abslinear.';
%S22=S22abslinear.';
 
%Layer parameters 
 
 %Layer 1
 Ei(1)= E(1); %Permittivity 
 t(1)= 0.9e-03;  %Layer Thickness (m)
 tand(1)= 0.001; %Loss tangent 
 
 %Layer 2
 Ei(2)= E(2); %Permittivity
 t(2)= 24e-03;  %Layer Thickness (m) 
 tand(2)= 0.001; %Loss tangent 
 
 %Layer 3
 Ei(3)= E(3); %Permittivity 
 t(3)= 0.9e-03;  %Layer Thickness (m) 
 tand(3)= 0.001; %Loss tangent 
 
 %Layer 4
 Ei(4)= E(4); %Permittivity 
 t(4)= 0.5e-3;  %Layer Thickness (m) 
 tand(4)= 0.01; %Loss tangent 
 
%  %Layer 5
%  Ei(5)= E(9); %Permittivity 
%  t(5)= 1000;  %Layer Thickness (m) 
%  tand(5)= E(10); %Loss tangent 
%  
%  %Layer 6
%  Ei(6)= E(11); %Permittivity 
%  t(6)= 0.5842e-2;  %Layer Thickness (m) 
%  tand(6)= E(12); %Loss tangent 
%  
%  %Layer 7
%  Ei(7)= E(13); %Permittivity 
%  t(7)= 0.0762e-2;  %Layer Thickness (m) 
%  tand(7)= E(14); %Loss tangent 
%  
%  %Layer 8
%  Ei(8)= E(15); %Permittivity 
%  t(8)= 0.3302e-2;  %Layer Thickness (m) 
%  tand(8)= E(16); %Loss tangent 
%  
%  %Layer 9
%  Ei(9)= E(17); %Permittivity 
%  t(9)= 0.0762e-2;  %Layer Thickness (m) 
%  tand(9)= E(18); %Loss tangent 
%  
%  %Layer 10
%  Ei(10)= E(19); %Permittivity 
%  t(10)= 1;  %Layer Thickness (m) 
%  tand(10)= E(20); %Loss tangent
 
 %Free Space Layer (Do not alter)
 Ei(N+1)= 1; %Permittivity
 t(N+1)= 1000;  %Layer Thickness (m) 
 tand(N+1)= 0; %Loss tangent 
 

theta=[0];

f=linspace(fmin*1e9,fmax*1e9,801); %Matrix with simulation frequencies
thetaradian=theta.*(pi/180); %Angle of incidence (Radian) 

for l=1:length(theta)
    sintheta(l)=sin(thetaradian(l)); 
    costheta(l)=cos(thetaradian(l));
end
 


for m=1:length(theta)
 
    sintheta1=sintheta(m);
    costheta1=costheta(m);
%Total reflection and transmission coefficients
for k =1:length(f); 
 lambda_freespace(k)=c/(f(k)); 
 Gamma=2*(pi/lambda_freespace(k));
 TotalMatrix=1;
 
 %w(k)=2*pi*f(k)*1e9; 
 
 %Calculate characteristic impedance of the layers 
 Z_w(k)=(1/sqrt(1-((fco/f(k)))^2));
 Er(1)=Ei(1)*(1-(j*tand(1)));
 Z(1)=(costheta1/sqrt(Er(1)-(sintheta1^2)))/Z_w(k);
 for i=2:N+1 
 Er(i)=Ei(i)*(1-(j*tand(i)));
 if pol==1 
 Z(i)=sqrt(Er(i)-(sintheta1^2))/(Er(i)*costheta1)/Z_w(k); 
 elseif pol==2 
 Z(i)=(costheta1/sqrt(Er(i)-(sintheta1^2)))/Z_w(k);  
 end 
 end 
 
 %Individual reflection and transmission coefficients of the layers 
 refl(1)=((Z(1)-1)/(Z(1)+1)); 
 trans(1)=sqrt(1-refl(1)^2); 
 for i=2:N+1 
 refl(i)=((Z(i)-Z(i-1))/(Z(i)+Z(i-1))); 
 trans(i)=sqrt(1-refl(i)^2);
 end 
 
 %Generating wave matrices 
 for i =1:(N)  
 M=exp(j*Gamma*t(i)*sqrt(Er(i)-(sintheta1^2))); 
 Mc=exp(-j*Gamma*t(i)*sqrt(Er(i)-(sintheta1^2)));
 TotalMatrix=TotalMatrix*(1/trans(i)*[M,refl(i)*Mc;refl(i)*M,Mc]);
 end 
 
 %Total reflection and transmission coefficients of the structure 
 TotalMatrix=1/trans(N+1)*TotalMatrix*[1 refl(N+1); refl(N+1) 1]; 
 reflection(k)=TotalMatrix(2,1)/TotalMatrix(1,1); 
 transmission(k)=1/TotalMatrix(1,1); 

end

 Transabs=abs(transmission);
 Reflabs=abs(reflection);
 Transabsdb=mag2db(Transabs);
 Reflabsdb=mag2db(Reflabs);



%Plot the transmission and reflection coefficients in dB:
  figure(1);
  plot(f/1e9,mag2db(abs(S11_DUT1)),'k-',f/1e9,Reflabsdb,'k--')
  grid on; 
  xlabel('Frequency (GHz)'); 
  ylabel('Reflection loss (dB)'); 
  legend('Measured','Matlab','Location','EastOutside');
  
  figure(2);
  plot(f/1e9,mag2db(abs(S21_DUT1)),'k-',f/1e9,Transabsdb,'k--')
  grid on; 
  xlabel('Frequency (GHz)'); 
  ylabel('Transmission loss (dB)'); 
  legend('Measured','Matlab','Location','EastOutside');

  for a=1:length(f);
curve1(a)=(abs(S21_DUT1(a)));
curve2(a)=Transabs(a);
E1(a)=(curve1(a)-curve2(a));
curve3(a)=(abs(S11_DUT1(a)));
curve4(a)=Reflabs(a);
E2(a)=(curve3(a)-curve4(a));


  end
end

ehandle=@Wall_Transmission_Optimization;
Error=(E1+E2);
