%############################################################### 
%TRANSMISSION AND REFLECTION THROUGH MULTILAYER DIELECTRIC WALLS 
%############################################################### 

function Error = ABCD(E)
 
%Simulation settings 
N = 1;       %number of layers 
fmin= 1;     %Minimum Frequency (GHz) 
fmax= 25;     %Maximum Frequency (GHz) 
polarization= 2;      %Polarization Type Parallel(Tm) (1), Perpendicular(Te) (2) 

%Optimization Parameters

z=1;     %Number of frequency bands

f_optim_low1=14; %Low Frequency band 1(GHz)
f_optim_high1=16; %High Frequency band 1(GHz)

f_optim_low2=18; %Low Frequency band 2(GHz)
f_optim_high2=20; %High Frequency band 2(GHz)

f_optim_low3=14; %Low Frequency band 2(GHz)
f_optim_high3=15; %High Frequency band 2(GHz)

f_optim_low4=13; %Low Frequency band 2(GHz)
f_optim_high4=14; %High Frequency band 2(GHz)

f_optim_low5=10; %Low Frequency band 2(GHz)
f_optim_high5=11; %High Frequency band 2(GHz)

%Constant values 
E0=8.85e-12;  
Mu0=12.5664e-7;  
c=1/sqrt(E0*Mu0); 
a=72.136e-3;
fco=2.078e9;
lambda_co=c/fco;
 
%Properties of the individual layers (uncomment the relevant layers) 
 
 %Layer 1
 Ei(1)= 3.23; %Permittivity 
 t(1)= E(1);  %Layer Thickness (m)
 tand(1)= 0.016; %Loss tangent 
 
%  %Layer 2
%  Ei(2)= 1.1; %Permittivity 
%  t(2)= E(2);  %Layer Thickness (m) 
%  tand(2)= 0.001; %Loss tangent 
%  
%  %Layer 3
%  Ei(3)= 3.23; %Permittivity 
%  t(3)= E(3);  %Layer Thickness (m) 
%  tand(3)= 0.016; %Loss tangent 
%  
%  %Layer 4
%  Ei(4)= 2.9; %Permittivity 
%  t(4)= E(4);  %Layer Thickness (m)
%  tand(4)= 0.01; %Loss tangent 
 
%  %Layer 5
%  Ei(5)= E(9); %Permittivity 
%  t(5)= 1000;  %Layer Thickness (m)
%  tand(5)= E(10); %Loss tangent 
%  
%  %Layer 6
%  Ei(6)= E(11); %Permittivity 
%  t(6)= 0.5842e-2;  %Layer Thickness (m) 
%  tand(6)= E(12); %Loss tangent 
%  
%  %Layer 7
%  Ei(7)= E(13); %Permittivity 
%  t(7)= 0.0762e-2;  %Layer Thickness (m) 
%  tand(7)= E(14); %Loss tangent 
%  
%  %Layer 8
%  Ei(8)= E(15); %Permittivity 
%  t(8)= 0.3302e-2;  %Layer Thickness (m) 
%  tand(8)= E(16); %Loss tangent 
%  
%  %Layer 9
%  Ei(9)= E(17); %Permittivity 
%  t(9)= 0.0762e-2;  %Layer Thickness (m) 
%  tand(9)= E(18); %Loss tangent 
%  
%  %Layer 10
%  Ei(10)= E(19); %Permittivity 
%  t(10)= 1;  %Layer Thickness (m) 
%  tand(10)= E(20); %Loss tangent
 
 %Free Space Layer
 Ei(N+1)= 1; %Permittivity 
 t(N+1)= 1000;  %Layer Thickness (m)
 tand(N+1)= 0; %Loss tangent 
 

theta= [0];

f=linspace(fmin*1e9,fmax*1e9,50); 
thetaradian=theta.*(pi/180); 

%Calculate frequency band 

if z==1
low1=floor((f_optim_low1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
high1=ceil((f_optim_high1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));

elseif z==2
    low1=floor((f_optim_low1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high1=ceil((f_optim_high1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low2=floor((f_optim_low2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high2=ceil((f_optim_high2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    
    
    elseif z==3
    low1=floor((f_optim_low1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high1=ceil((f_optim_high1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low2=floor((f_optim_low2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high2=ceil((f_optim_high2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low3=floor((f_optim_low3*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high3=ceil((f_optim_high3*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
        
    
    elseif z==4
    low1=floor((f_optim_low1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high1=ceil((f_optim_high1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low2=floor((f_optim_low2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high2=ceil((f_optim_high2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low3=floor((f_optim_low3*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high3=ceil((f_optim_high3*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low4=floor((f_optim_low2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high4=ceil((f_optim_high2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
        
        
    elseif z==5
    low1=floor((f_optim_low1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high1=ceil((f_optim_high1*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low2=floor((f_optim_low2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high2=ceil((f_optim_high2*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low3=floor((f_optim_low3*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high3=ceil((f_optim_high3*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low4=floor((f_optim_low4*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high4=ceil((f_optim_high4*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    low5=floor((f_optim_low5*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    high5=ceil((f_optim_high5*1e9-fmin*1e9)/(((fmax-fmin)*1e9)/length(f)));
    
    
end
    

    sintheta=sin(thetaradian); 
    costheta=cos(thetaradian);

 

for m=1:length(theta)
 
    sintheta1=sintheta(m);
    costheta1=costheta(m);

    %Total reflection and transmission coefficients
    for k =1:length(f); 
    lambda_freespace(k)=c/(f(k)); 
    Gamma=2*(pi/lambda_freespace(k));
    TotalMatrix=1;
 
 
 %Characteristic layer impedance 
 Er(1)=Ei(1)*(1-(j*tand(1)));
 Z(1)=(costheta1/sqrt(Er(1)-(sintheta1^2)));
 for i=2:N+1 
 Er(i)=Ei(i)*(1-(j*tand(i)));
 if polarization==1 
 Z(i)=sqrt(Er(i)-(sintheta1^2))/(Er(i)*costheta1); 
 elseif polarization==2 
 Z(i)=(costheta1/sqrt(Er(i)-(sintheta1^2)));  
 end 
 end 
 
 %Reflection and transmission for the different layers 
 refl(1)=((Z(1)-1)/(Z(1)+1)); 
 trans(1)=sqrt(1-refl(1)^2); 
 for i=2:N+1 
 refl(i)=((Z(i)-Z(i-1))/(Z(i)+Z(i-1))); 
 trans(i)=sqrt(1-refl(i)^2);
 end 
 
 %Wave matrix calculation
 for i =1:(N)  
 M=exp(j*Gamma*t(i)*sqrt(Er(i)-(sintheta1^2))); 
 Mc=exp(-j*Gamma*t(i)*sqrt(Er(i)-(sintheta1^2)));
 TotalMatrix=TotalMatrix*(1/trans(i)*[M,refl(i)*Mc;refl(i)*M,Mc]);
 end 
 
 %Total reflection and transmission coefficients of the structure 
 TotalMatrix=1/trans(N+1)*TotalMatrix*[1 refl(N+1); refl(N+1) 1]; 
 reflection(k)=TotalMatrix(2,1)/TotalMatrix(1,1); 
 transmission(k)=1/TotalMatrix(1,1); 

end

 Transabs=abs(transmission);
 Reflabs=abs(reflection);
 Transabsdb=mag2db(Transabs);
 Reflabsdb=mag2db(Reflabs);



%Plot the transmission and reflection coefficients in dB:
  figure(1);
  plot(f/1e9,Reflabsdb,'k');
  grid; 
  xlabel('Frequency (GHz)'); 
  ylabel('Reflection loss (dB)');
  figure(2);
  plot(f/1e9,Transabsdb,'k');
  grid;
  xlabel('Frequency (GHz)'); 
  ylabel('Transmission loss (dB)'); 

  for a=1:length(f);
    E(a)=Reflabsdb(a);
  end
end

ehandle=@Wall_Transmission_Optimization_frequency_band;

if z==1
Error=sum(E([low1:high1]));

    elseif z==2
    Error=sum(E([low1:high1]))+sum(E([low2:high2]));
    
    elseif z==3
    Error=E([low1:high1 low2:high2 low3:high3]);    
    
    elseif z==4
    Error=E([low1:high1 low2:high2 low3:high3 low4:high4]);
    
        
    
    elseif z==5
    Error=E([low1:high1 low2:high2 low3:high3 low4:high4 low5:high5]);
    
       
end